@@ -20,16 +20,15 @@ COORDINATE_FORMAT: Final[str] = '({:.2f}, {:.2f}, {:.2f})'
 
 
 class DrawableSkeleton(Group):
-    def __init__(self, joint_points: Points, joint_lines: List[Line],
+    def __init__(self, joint_points: List[Points], joint_lines: List[Line],
                  joint_names: List[Text] = None, joint_coordinates: List[Text] = None):
-        points: List[Drawable] = [joint_points]
-        drawable_objects: List[Drawable] = points + joint_lines
+        drawable_objects: List[Drawable] = joint_points + joint_lines
         if joint_names is not None:
             drawable_objects += joint_names
         if joint_coordinates is not None:
             drawable_objects += joint_coordinates
         super().__init__(drawable_objects)
-        self.joint_points: Points = joint_points
+        self.joint_points: List[Points] = joint_points
         self.joint_lines: List[Line] = joint_lines
         self.joint_names: List[Text] = joint_names
         self.joint_coordinates: List[Text] = joint_coordinates
@@ -44,39 +43,55 @@ class Skeleton:
         self.color: Color = color
 
     def to_drawable_skeleton(self) -> DrawableSkeleton:
-        joint_points: Points = self.__get_joint_points()
+        joint_points: List[Points] = self.__get_joint_points()
         joint_lines: List[Line] = self.__get_joint_lines()
         return DrawableSkeleton(joint_points, joint_lines)
 
-    def to_drawable_skeleton_with_coordinates(self) -> DrawableSkeleton:
-        joint_points: Points = self.__get_joint_points()
-        joint_lines: List[Line] = self.__get_joint_lines()
-        joint_coordinates: List[Text] = self.__get_joint_coordinates()
-        return DrawableSkeleton(joint_points, joint_lines, joint_coordinates=joint_coordinates)
-
     def to_drawable_skeleton_with_names(self) -> DrawableSkeleton:
-        joint_points: Points = self.__get_joint_points()
+        joint_points: List[Points] = self.__get_joint_points()
         joint_lines: List[Line] = self.__get_joint_lines()
         joint_names: List[Text] = self.__get_joint_names()
         return DrawableSkeleton(joint_points, joint_lines, joint_names=joint_names)
 
+    def to_drawable_skeleton_with_coordinates(self) -> DrawableSkeleton:
+        joint_points: List[Points] = self.__get_joint_points()
+        joint_lines: List[Line] = self.__get_joint_lines()
+        joint_coordinates: List[Text] = self.__get_joint_coordinates()
+        return DrawableSkeleton(joint_points, joint_lines, joint_coordinates=joint_coordinates)
+
     def to_drawable_skeleton_for_video(self) -> DrawableSkeleton:
-        joint_points: Points = self.__get_joint_points()
+        joint_points: List[Points] = self.__get_joint_points_for_video()
         joint_lines: List[Line] = self.__get_joint_lines_for_video()
         return DrawableSkeleton(joint_points, joint_lines)
 
+    def to_drawable_skeleton_for_video_with_names(self) -> DrawableSkeleton:
+        joint_points: List[Points] = self.__get_joint_points_for_video()
+        joint_lines: List[Line] = self.__get_joint_lines_for_video()
+        joint_names: List[Text] = self.__get_joint_names_for_video()
+        return DrawableSkeleton(joint_points, joint_lines, joint_names=joint_names)
+
     def to_drawable_skeleton_for_video_with_coordinates(self) -> DrawableSkeleton:
-        joint_points: Points = self.__get_joint_points()
+        joint_points: List[Points] = self.__get_joint_points_for_video()
         joint_lines: List[Line] = self.__get_joint_lines_for_video()
         joint_coordinates: List[Text] = self.__get_joint_coordinates_for_video()
         return DrawableSkeleton(joint_points, joint_lines, joint_coordinates=joint_coordinates)
 
-    def __get_joint_points(self) -> Points:
+    def __get_joint_points(self) -> List[Points]:
         skeleton_joint_colors: np.ndarray = self.__get_joint_colors()
-        return k3d.points(
-            positions=self.joint_positions, point_size=self.part_size,
-            shader='mesh', colors=skeleton_joint_colors
-        )
+        return [k3d.points(
+            positions=self.joint_positions[line_index], point_size=self.part_size,
+            shader='mesh', color=int(skeleton_joint_colors[line_index])
+        ) for line_index in range(self.joint_set.number_of_joints)]
+
+    def __get_joint_points_for_video(self) -> List[Points]:
+        skeleton_joint_colors: np.ndarray = self.__get_joint_colors()
+        return [k3d.points(
+            positions={
+                current_timestamp[0]: current_timestamp[1][line_index]
+                for current_timestamp in self.joint_positions.items()
+            }, color=int(skeleton_joint_colors[line_index]),
+            point_size=self.part_size, shader='mesh'
+        ) for line_index in range(self.joint_set.number_of_joints)]
 
     def __get_joint_lines(self) -> List[Line]:
         skeleton_line_colors: np.ndarray = self.__get_line_colors()
@@ -86,9 +101,8 @@ class Skeleton:
                 self.joint_positions[self.joint_set.limb_graph[line_index][1]]
             ], width=self.part_size / 2.2,
             color=int(skeleton_line_colors[line_index]),
-            shader='mesh')
-            for line_index in range(len(self.joint_set.limb_graph))
-        ]
+            shader='mesh'
+        ) for line_index in range(len(self.joint_set.limb_graph))]
 
     def __get_joint_lines_for_video(self) -> List[Line]:
         skeleton_line_colors: np.ndarray = self.__get_line_colors()
@@ -100,43 +114,48 @@ class Skeleton:
                 ]) for current_timestamp in self.joint_positions.items()
             }, width=self.part_size / 2.2,
             color=int(skeleton_line_colors[line_index]),
-            shader='mesh')
-            for line_index in range(len(self.joint_set.limb_graph))
-        ]
+            shader='mesh'
+        ) for line_index in range(len(self.joint_set.limb_graph))]
 
     def __get_joint_names(self) -> List[Text]:
         return [k3d.text(
-            text=self.joint_set.names[i],
-            position=self.joint_positions[i],
-            size=DEFAULT_TEXT_SIZE, label_box=False, color=DEFAULT_COLORS.get('black'))
-            for i in range(self.joint_set.number_of_joints)
-        ]
+            text=self.joint_set.names[joint_index],
+            position=self.joint_positions[joint_index],
+            size=DEFAULT_TEXT_SIZE, label_box=False, color=DEFAULT_COLORS.get('black')
+        ) for joint_index in range(self.joint_set.number_of_joints)]
+
+    def __get_joint_names_for_video(self) -> List[Text]:
+        return [k3d.text(
+            text=self.joint_set.names[joint_index],
+            position={
+                current_timestamp[0]: current_timestamp[1][joint_index]
+                for current_timestamp in self.joint_positions.items()
+            }, size=DEFAULT_TEXT_SIZE, label_box=False, color=DEFAULT_COLORS.get('black')
+        ) for joint_index in range(self.joint_set.number_of_joints)]
 
     def __get_joint_coordinates(self) -> List[Text]:
         return [k3d.text(
             text=COORDINATE_FORMAT.format(
-                self.joint_positions[i][0],
-                self.joint_positions[i][1],
-                self.joint_positions[i][2]
-            ), position= self.joint_positions[i],
-            size=DEFAULT_TEXT_SIZE, label_box=False, color=DEFAULT_COLORS.get('black'))
-            for i in range(self.joint_set.number_of_joints)
-        ]
+                self.joint_positions[joint_index][0],
+                self.joint_positions[joint_index][1],
+                self.joint_positions[joint_index][2]
+            ), position=self.joint_positions[joint_index],
+            size=DEFAULT_TEXT_SIZE, label_box=False, color=DEFAULT_COLORS.get('black')
+        ) for joint_index in range(self.joint_set.number_of_joints)]
 
     def __get_joint_coordinates_for_video(self) -> List[Text]:
         return [k3d.text(
             text={
                 current_timestamp[0]: COORDINATE_FORMAT.format(
-                    current_timestamp[1][i][0],
-                    current_timestamp[1][i][0],
-                    current_timestamp[1][i][0])
+                    current_timestamp[1][joint_index][0],
+                    current_timestamp[1][joint_index][0],
+                    current_timestamp[1][joint_index][0])
                 for current_timestamp in self.joint_positions.items()
             }, position={
-                current_timestamp[0]: current_timestamp[1][i]
+                current_timestamp[0]: current_timestamp[1][joint_index]
                 for current_timestamp in self.joint_positions.items()
-            }, size=DEFAULT_TEXT_SIZE, label_box=False, color=DEFAULT_COLORS.get('black'))
-            for i in range(self.joint_set.number_of_joints)
-        ]
+            }, size=DEFAULT_TEXT_SIZE, label_box=False, color=DEFAULT_COLORS.get('black')
+        ) for joint_index in range(self.joint_set.number_of_joints)]
 
     def __get_joint_colors(self) -> np.ndarray:
         joint_colors_shape: Tuple[int] = (self.joint_set.number_of_joints,)
@@ -147,8 +166,10 @@ class Skeleton:
             joint_colors[self.joint_set.center_joint_indices] = DEFAULT_COLORS.get('white')
             return joint_colors
         else:
-            return np.full(shape=joint_colors_shape,
-                           fill_value=self.__get_color(self.color), dtype='uint32')
+            return np.full(
+                shape=joint_colors_shape,
+                fill_value=self.__get_color(self.color),
+                dtype='uint32')
 
     def __get_line_colors(self) -> np.ndarray:
         line_colors_shape: Tuple[int] = (self.joint_set.number_of_joints - 1,)
@@ -162,8 +183,7 @@ class Skeleton:
             return np.full(
                 shape=line_colors_shape,
                 fill_value=self.__get_color(self.color),
-                dtype='uint32'
-            )
+                dtype='uint32')
 
     @staticmethod
     def __get_color(color: Color) -> int:
