@@ -5,7 +5,7 @@ import ipywidgets as widgets
 import k3d
 import numpy as np
 from IPython.display import display
-from ipywidgets import Play, Checkbox
+from ipywidgets import Play, Checkbox, IntSlider, Button
 from k3d.plot import Plot
 
 from .jointset import JointSet, MuPoTSJoints, OpenPoseJoints, CocoExJoints, PanopticJoints, Common14Joints
@@ -13,10 +13,7 @@ from .objects import Skeleton, DrawableSkeleton, Color, Positions
 
 
 class FrameUpdater:
-    def __init__(self, skeletons: List[DrawableSkeleton], frames: np.ndarray, joint_set: JointSet, video_player: Play):
-        self.skeletons = skeletons
-        self.frames = frames
-        self.joint_set: JointSet = joint_set
+    def __init__(self, video_player: Play):
         self.video_player: Play = video_player
 
     def update_to_next_frame(self, button) -> None:
@@ -50,9 +47,7 @@ class SkeletonVisualizer:
             skeleton_converter = Skeleton.to_drawable_skeleton
         self.__create_skeleton_plot(skeletons, skeleton_converter, colors)
         self.plot.display()
-        if include_names:
-            self.__link_joint_name_visibility_with_checkbox()
-            display(self.joint_names_visible)
+        self.__display_checkboxes(include_names, include_coordinates)
 
     def visualize_video_from_file(self, file_name: str, colors: List[Color] = None, fps: int = 15,
                                   include_names: bool = False, include_coordinates: bool = False) -> None:
@@ -70,26 +65,23 @@ class SkeletonVisualizer:
         skeleton_timestamps: List[Dict[str, np.ndarray]] = self.__get_skeleton_positions_timestamps(frames)
         self.__assert_include_arguments(include_names, include_coordinates)
         if include_names:
-            skeleton_converter = None
+            skeleton_converter = Skeleton.to_drawable_skeleton_for_video_with_names
         elif include_coordinates:
             skeleton_converter = Skeleton.to_drawable_skeleton_for_video_with_coordinates
         else:
             skeleton_converter = Skeleton.to_drawable_skeleton_for_video
-        self.__create_skeleton_plot(
-            skeletons=first_frame, skeleton_converter=skeleton_converter,
-            colors=colors, positions=skeleton_timestamps)
+        self.__create_skeleton_plot(first_frame, skeleton_converter, colors, skeleton_timestamps)
         self.plot.display()
         self.__display_video_player(fps, frames)
+        self.__display_checkboxes(include_names, include_coordinates)
 
     @staticmethod
     def __get_skeleton_positions_timestamps(frames: np.ndarray) -> List[Dict[str, np.ndarray]]:
         frames_swapped: np.ndarray = np.swapaxes(frames, 0, 1)
-        return [
-            {
-                str(timestamp_index): frames_swapped[current_frame_index][timestamp_index]
-                for timestamp_index in range(len(frames_swapped[current_frame_index]))
-            } for current_frame_index in range(len(frames_swapped))
-        ]
+        return [{
+            str(timestamp_index): frames_swapped[current_frame_index][timestamp_index]
+            for timestamp_index in range(len(frames_swapped[current_frame_index]))
+        } for current_frame_index in range(len(frames_swapped))]
 
     def __create_skeleton_plot(self, skeletons: np.ndarray, skeleton_converter: Callable[[Skeleton], DrawableSkeleton],
                                colors: List[Color], positions: Optional[Positions] = None) -> None:
@@ -102,7 +94,7 @@ class SkeletonVisualizer:
         self.__add_skeletons_to_plot(drawable_skeletons)
 
     def __init_skeleton_plot(self, skeletons: np.ndarray) -> None:
-        self.plot = k3d.plot(antialias=1, camera_auto_fit=False)
+        self.plot = k3d.plot(antialias=0, camera_auto_fit=False)
         centroid: np.ndarray = np.average(np.average(skeletons, axis=0), axis=0)
         camera_up_vector: np.ndarray = np.zeros(shape=(3,))
         for line_indices in self.joint_set.vertically_aligned_line_indices:
@@ -138,13 +130,12 @@ class SkeletonVisualizer:
             value=0,
             min=0, max=frames.shape[0] - 1,
             step=1, interval=1000 / fps,
-            description='Press play', disabled=False
-        )
-        frame_updater = FrameUpdater(self.skeletons, frames, self.joint_set, video_player)
-        frame_slider = widgets.IntSlider(value=0, min=0, max=frames.shape[0] - 1, step=1, description='Frame')
-        next_frame_button = widgets.Button(description='Next frame')
+            description='Press play', disabled=False)
+        frame_updater = FrameUpdater(video_player)
+        frame_slider = IntSlider(value=0, min=0, max=frames.shape[0] - 1, step=1, description='Frame')
+        next_frame_button = Button(description='Next frame')
         next_frame_button.on_click(frame_updater.update_to_next_frame)
-        previous_frame_button = widgets.Button(description='Prev frame')
+        previous_frame_button = Button(description='Previous frame')
         previous_frame_button.on_click(frame_updater.update_to_previous_frame)
         widgets.jslink((video_player, 'value'), (frame_slider, 'value'))
         widgets.jslink((video_player, 'value'), (self.plot, 'time'))
@@ -170,11 +161,24 @@ class SkeletonVisualizer:
         if include_names is True and include_coordinates is True:
             raise AttributeError('Either names or coordinates can be showed, but not both.')
 
+    def __display_checkboxes(self, include_names: bool, include_coordinates: bool) -> None:
+        if include_names:
+            self.__link_joint_name_visibility_with_checkbox()
+            display(self.joint_names_visible)
+        if include_coordinates:
+            self.__link_joint_coordinate_visibility_with_checkbox()
+            display(self.joint_coordinates_visible)
+
     def __link_joint_name_visibility_with_checkbox(self) -> None:
         for skeleton in self.skeletons:
             for joint_name in skeleton.joint_names:
                 widgets.jslink((joint_name, 'visible'), (self.joint_names_visible, 'value'))
 
+    def __link_joint_coordinate_visibility_with_checkbox(self) -> None:
+        for skeleton in self.skeletons:
+            for joint_coordinate in skeleton.joint_coordinates:
+                widgets.jslink((joint_coordinate, 'visible'), (self.joint_coordinates_visible, 'value'))
+
 
 class MuPoTSVisualizer(SkeletonVisualizer):
     def __init__(self, size_scalar: float = 1.0):
